@@ -3,11 +3,12 @@ Main interface for workmailmessageflow service type definitions.
 
 Usage::
 
-    from mypy_boto3.workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
+    ```python
+    from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
 
     data: GetRawMessageContentResponseTypeDef = {...}
+    ```
 """
-import sys
 from typing import IO
 
 if sys.version_info >= (3, 8):
